@@ -2,15 +2,18 @@
 use alloc::vec::Vec;
 #[cfg(not(feature = "with_serde"))]
 use binary_sv2::binary_codec_sv2::{self, free_vec, free_vec_2, CVec, CVec2};
+#[cfg(not(feature = "with_serde"))]
+use binary_sv2::Error;
 use binary_sv2::{Deserialize, Serialize};
-use binary_sv2::{Error, Seq064K, Str0255, B016M, B064K};
+use binary_sv2::{Seq064K, Str0255, B016M, B064K};
+#[cfg(not(feature = "with_serde"))]
 use core::convert::TryInto;
 
 /// ## RequestTransactionData (Client -> Server)
 /// A request sent by the Job Negotiator to the Template Provider which requests the set of
 /// transaction data for all transactions (excluding the coinbase transaction) included in a block, as
 /// well as any additional data which may be required by the Pool to validate the work.
-#[derive(Serialize, Deserialize, Debug, Clone)]
+#[derive(Serialize, Deserialize, Debug, Clone, PartialEq, Eq)]
 #[repr(C)]
 pub struct RequestTransactionData {
     /// The template_id corresponding to a NewTemplate message.
@@ -44,7 +47,7 @@ pub struct RequestTransactionData {
 /// code-release to activation (as any sane fork would have to have) and there being some
 /// in-Template Negotiation Protocol signaling of support for the new fork (e.g. for soft-forks
 /// activated using [BIP 9](TODO link)).
-#[derive(Serialize, Deserialize, Debug, Clone)]
+#[derive(Serialize, Deserialize, Debug, Clone, PartialEq, Eq)]
 pub struct RequestTransactionDataSuccess<'decoder> {
     /// The template_id corresponding to a NewTemplate/RequestTransactionData message.
     pub template_id: u64,
@@ -64,6 +67,7 @@ pub struct CRequestTransactionDataSuccess {
     transaction_list: CVec2,
 }
 
+#[cfg(not(feature = "with_serde"))]
 impl<'a> CRequestTransactionDataSuccess {
     #[cfg(not(feature = "with_serde"))]
     pub fn to_rust_rep_mut(&'a mut self) -> Result<RequestTransactionDataSuccess<'a>, Error> {
@@ -107,7 +111,7 @@ impl<'a> From<RequestTransactionDataSuccess<'a>> for CRequestTransactionDataSucc
     }
 }
 
-#[derive(Serialize, Deserialize, Debug, Clone)]
+#[derive(Serialize, Deserialize, Debug, Clone, PartialEq, Eq)]
 pub struct RequestTransactionDataError<'decoder> {
     /// The template_id corresponding to a NewTemplate/RequestTransactionData message.
     pub template_id: u64,
@@ -125,6 +129,7 @@ pub struct CRequestTransactionDataError {
     error_code: CVec,
 }
 
+#[cfg(not(feature = "with_serde"))]
 impl<'a> CRequestTransactionDataError {
     #[cfg(not(feature = "with_serde"))]
     pub fn to_rust_rep_mut(&'a mut self) -> Result<RequestTransactionDataError<'a>, Error> {
