@@ -2,8 +2,11 @@
 use alloc::vec::Vec;
 #[cfg(not(feature = "with_serde"))]
 use binary_sv2::binary_codec_sv2::{self, free_vec, CVec};
+#[cfg(not(feature = "with_serde"))]
+use binary_sv2::Error;
+use binary_sv2::U256;
 use binary_sv2::{Deserialize, Serialize};
-use binary_sv2::{Error, U256};
+#[cfg(not(feature = "with_serde"))]
 use core::convert::TryInto;
 
 /// ## SetNewPrevHash (Server -> Client)
@@ -14,7 +17,7 @@ use core::convert::TryInto;
 /// indicating the client MUST begin mining on that template as soon as possible.
 /// TODO: Define how many previous works the client has to track (2? 3?), and require that the
 /// server reference one of those in SetNewPrevHash.
-#[derive(Serialize, Deserialize, Debug, Clone)]
+#[derive(Serialize, Deserialize, Debug, Clone, PartialEq, Eq)]
 pub struct SetNewPrevHash<'decoder> {
     /// template_id referenced in a previous NewTemplate message.
     pub template_id: u64,
@@ -43,6 +46,7 @@ pub struct CSetNewPrevHash {
     target: CVec,
 }
 
+#[cfg(not(feature = "with_serde"))]
 impl<'a> CSetNewPrevHash {
     #[cfg(not(feature = "with_serde"))]
     pub fn to_rust_rep_mut(&'a mut self) -> Result<SetNewPrevHash<'a>, Error> {
