@@ -2,8 +2,11 @@
 use alloc::vec::Vec;
 #[cfg(not(feature = "with_serde"))]
 use binary_sv2::binary_codec_sv2::{self, free_vec, CVec};
+#[cfg(not(feature = "with_serde"))]
+use binary_sv2::Error;
+use binary_sv2::B064K;
 use binary_sv2::{Deserialize, Serialize};
-use binary_sv2::{Error, B064K};
+#[cfg(not(feature = "with_serde"))]
 use core::convert::TryInto;
 
 /// ## SubmitSolution (Client -> Server)
@@ -11,7 +14,7 @@ use core::convert::TryInto;
 /// [`crate::SetNewPrevHash.target`], the client MUST immediately send this message, and the server
 /// MUST then immediately construct the corresponding full block and attempt to propagate it to
 /// the Bitcoin network.
-#[derive(Serialize, Deserialize, Debug, Clone)]
+#[derive(Serialize, Deserialize, Debug, Clone, PartialEq, Eq)]
 pub struct SubmitSolution<'decoder> {
     /// The template_id field as it appeared in NewTemplate.
     pub template_id: u64,
@@ -42,6 +45,7 @@ pub struct CSubmitSolution {
     coinbase_tx: CVec,
 }
 
+#[cfg(not(feature = "with_serde"))]
 impl<'a> CSubmitSolution {
     #[cfg(not(feature = "with_serde"))]
     pub fn to_rust_rep_mut(&'a mut self) -> Result<SubmitSolution<'a>, Error> {
